import{_ as l}from"./Login.vue_vue_type_script_setup_true_lang.5433a29e.js";import{d as m,eo as f,ea as b,o as g,Y as y,b as w,u as n,a0 as k}from"./index.0396e68e.js";import{u as h}from"./workspaceStore.63e90c7b.js";import"./Logo.008d40fa.js";import"./string.dc823a05.js";import"./CircularLoading.11766de6.js";import"./index.cfde0a4b.js";import"./index.445b73ea.js";import"./url.892c62bd.js";import"./colorHelpers.1afbbca5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="53ea2765-cba9-4292-9f87-ebeed4cb1384",e._sentryDebugIdIdentifier="sentry-dbid-53ea2765-cba9-4292-9f87-ebeed4cb1384")}catch{}})();const v={class:"runner"},I=m({__name:"Login",setup(e){const o=f(),t=b(),r=h(),_=async()=>{const{redirect:a,...s}=t.query;if(a){await o.push({path:a,query:s,params:t.params});return}o.push({name:"playerHome",query:s})};return(a,s)=>{var c,d,p,u,i;return g(),y("div",v,[w(l,{"logo-url":(d=(c=n(r).state.workspace)==null?void 0:c.logoUrl)!=null?d:void 0,"brand-name":(p=n(r).state.workspace)==null?void 0:p.brandName,locale:(i=(u=n(r).state.workspace)==null?void 0:u.language)!=null?i:"en",onDone:_},null,8,["logo-url","brand-name","locale"])])}}});const H=k(I,[["__scopeId","data-v-ce854d6f"]]);export{H as default};
//# sourceMappingURL=Login.2ecc7f77.js.map
