import{a0 as n,o as a,Y as o,$ as s,a as d,S as r}from"./index.0396e68e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="ca52d16a-9622-49a5-abbe-f8af158aefe8",e._sentryDebugIdIdentifier="sentry-dbid-ca52d16a-9622-49a5-abbe-f8af158aefe8")}catch{}})();const f={},c={class:"base-layout"},i={class:"base-middle"},u={key:0,class:"base-footer"};function _(e,t){return a(),o("div",c,[s(e.$slots,"sidebar",{},void 0,!0),d("section",i,[s(e.$slots,"navbar",{},void 0,!0),s(e.$slots,"content",{},void 0,!0),e.$slots.footer?(a(),o("section",u,[s(e.$slots,"footer",{},void 0,!0)])):r("",!0)])])}const y=n(f,[["render",_],["__scopeId","data-v-9ad5be20"]]);export{y as B};
//# sourceMappingURL=BaseLayout.ad0c8bf8.js.map
