import{d,o as n,Y as s,a,$ as r,ed as l,a0 as c}from"./index.0396e68e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="63efd151-bb48-45cd-80dd-6cf5e6a14a5f",e._sentryDebugIdIdentifier="sentry-dbid-63efd151-bb48-45cd-80dd-6cf5e6a14a5f")}catch{}})();const _={class:"content-layout"},f=d({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,o)=>(n(),s("div",_,[a("div",{class:l(["centered-layout",{"full-width":t.fullWidth}])},[r(t.$slots,"default",{},void 0,!0)],2)]))}});const i=c(f,[["__scopeId","data-v-6397d501"]]);export{i as C};
//# sourceMappingURL=ContentLayout.da1c7798.js.map
