import{cM as n}from"./index.0396e68e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="c7c22d30-d857-49c4-be17-a1a0e8dae9ea",e._sentryDebugIdIdentifier="sentry-dbid-c7c22d30-d857-49c4-be17-a1a0e8dae9ea")}catch{}})();const t=(e,d,r)=>{n.error({message:e,description:d,onClick:r})};export{t as p};
//# sourceMappingURL=popupNotifcation.17433f53.js.map
