import{C as t,E as d,K as i,a as c,M as b,c as f,P as l,R as y,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.7e6f41d2.js";import"./index.0396e68e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="62b0bd89-9cc9-4ed9-96ae-f711b8cb4c18",e._sentryDebugIdIdentifier="sentry-dbid-62b0bd89-9cc9-4ed9-96ae-f711b8cb4c18")}catch{}})();export{t as CancellationTokenSource,d as Emitter,i as KeyCode,c as KeyMod,b as MarkerSeverity,f as MarkerTag,l as Position,y as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.971823a7.js.map
