import{d as i,eo as m,ea as p,o as l,c as f,w as c,u as n,Y as _,eb as g,b as y,a as v,e9 as w,aS as k}from"./index.0396e68e.js";import{A as I,T}from"./TabPane.b5e1cdd3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="abb9a7fc-50ba-4452-98a0-01c1e2d05ec2",e._sentryDebugIdIdentifier="sentry-dbid-abb9a7fc-50ba-4452-98a0-01c1e2d05ec2")}catch{}})();const B=i({__name:"TablesTabs",setup(e){const a=m(),t=p(),u=String(t.name),d=t.params.projectId,r=[{label:"Tables list",value:"tables"},{label:"Diagram view",value:"tables-diagram"},{label:"Run SQL",value:"sql"}],b=o=>{a.push({name:String(o),params:{projectId:d}})};return(o,D)=>(l(),f(n(T),{"active-key":n(u),options:r,"onUpdate:activeKey":b},{default:c(()=>[(l(),_(k,null,g(r,s=>y(n(I),{key:s.value,name:s.value},{tab:c(()=>[v("span",null,w(s.label),1)]),_:2},1032,["name"])),64))]),_:1},8,["active-key"]))}});export{B as _};
//# sourceMappingURL=TablesTabs.vue_vue_type_script_setup_true_lang.6ca81f2e.js.map
