import{P as f}from"./PlayerNavbar.bb3fd441.js";import{d as g,eo as b,ea as c,e as h,f as y,r as k,o as i,Y as v,u as a,c as w,S as L,a as C,b as I,a0 as N}from"./index.0396e68e.js";import{u as V}from"./workspaceStore.63e90c7b.js";import"./metadata.edcbc4f9.js";import"./PhWebhooksLogo.vue.834c9249.js";import"./LoadingOutlined.56cdefbf.js";import"./PhSignOut.vue.5666dae0.js";import"./index.f55d3423.js";import"./Avatar.546066ac.js";import"./url.892c62bd.js";import"./colorHelpers.1afbbca5.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="2ba2bd9d-e55b-4e44-9103-6ccbcd518311",o._sentryDebugIdIdentifier="sentry-dbid-2ba2bd9d-e55b-4e44-9103-6ccbcd518311")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=b(),t=V(),d=c().path,n=h(null),u=async({path:s,id:r})=>{n.value=r,await e.push({path:`/${s}`}),n.value=null},l=()=>{e.push({name:"playerLogin"})},p=()=>{e.push({name:"playerLogin"})},_=y(()=>!!c().meta.hideLogin);return(s,r)=>{const m=k("RouterView");return i(),v("div",x,[a(t).state.workspace?(i(),w(f,{key:0,"current-path":a(d),"hide-login":_.value,"runner-data":a(t).state.workspace,loading:n.value,onNavigate:u,onLoginClick:p,onLogoutClick:l},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(m)])])}}});const A=N(D,[["__scopeId","data-v-f095bece"]]);export{A as default};
//# sourceMappingURL=Main.670ddd81.js.map
