import{a0 as t,r as c,o as s,c as d}from"./index.0396e68e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="197ef0d2-b51f-4a65-b261-18b14c48ddc5",e._sentryDebugIdIdentifier="sentry-dbid-197ef0d2-b51f-4a65-b261-18b14c48ddc5")}catch{}})();const r={};function _(e,o){const n=c("RouterView");return s(),d(n,{class:"router"})}const f=t(r,[["render",_],["__scopeId","data-v-3c2b9654"]]);export{f as default};
//# sourceMappingURL=Home.b2bb5b2a.js.map
