import{d as o,o as s,Y as d,b as a,u as r,by as _,a0 as f}from"./index.0396e68e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="2f2b9e0d-d020-413f-84fe-ef856b8c756f",e._sentryDebugIdIdentifier="sentry-dbid-2f2b9e0d-d020-413f-84fe-ef856b8c756f")}catch{}})();const c={class:"centered"},i=o({__name:"LoadingContainer",setup(e){return(n,t)=>(s(),d("div",c,[a(r(_))]))}});const u=f(i,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.8b8d6dac.js.map
