import"./index.0396e68e.js";(function(){try{var x=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(x._sentryDebugIds=x._sentryDebugIds||{},x._sentryDebugIds[d]="4b7fd055-8532-4d73-aad2-08c225d08126",x._sentryDebugIdIdentifier="sentry-dbid-4b7fd055-8532-4d73-aad2-08c225d08126")}catch{}})();const t=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(x){const d=Math.random()*16|0;return(x=="x"?d:d&3|8).toString(16)});export{t as u};
//# sourceMappingURL=uuid.1da3d59d.js.map
