import{_ as n}from"./TasksView.vue_vue_type_script_setup_true_lang.6fd739b2.js";import{L as i}from"./tasksController.9fed01d7.js";import{d as p,o as d,c,w as a,b as o,aG as _,u as s,dd as m,a0 as l}from"./index.0396e68e.js";import{C as u}from"./ContentLayout.da1c7798.js";import"./metadata.edcbc4f9.js";import"./PhWebhooksLogo.vue.834c9249.js";import"./ant-design.8b815b73.js";import"./string.dc823a05.js";import"./dayjs.82e48647.js";import"./index.e1b1a35a.js";import"./gateway.157f1e61.js";import"./popupNotifcation.17433f53.js";import"./scripts.79d2de54.js";import"./record.0e62b813.js";import"./linters.13eb7d79.js";import"./asyncComputed.fdf54570.js";import"./polling.14117eb9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="2c05732a-52dc-4d94-b727-b0484e37e8ae",e._sentryDebugIdIdentifier="sentry-dbid-2c05732a-52dc-4d94-b727-b0484e37e8ae")}catch{}})();const f=p({__name:"Tasks",setup(e){const t=new i;return(r,y)=>(d(),c(u,null,{default:a(()=>[o(s(m),null,{default:a(()=>[_("Tasks")]),_:1}),o(n,{class:"tasks",api:s(t),stages:null,editor:""},null,8,["api"])]),_:1}))}});const G=l(f,[["__scopeId","data-v-10aa4cc9"]]);export{G as default};
//# sourceMappingURL=Tasks.c91a5c65.js.map
