import{k as i,T as n,m as r,P as o,C as d,M as p,s as c,n as s,p as f,q as m,t as u,v as g}from"./index.0396e68e.js";import{s as y,c as l,a}from"./workspaceStore.63e90c7b.js";import{_ as b}from"./App.vue_vue_type_style_index_0_lang.8c886061.js";import"./url.892c62bd.js";import"./colorHelpers.1afbbca5.js";import"./PlayerConfigProvider.88327aee.js";import"./index.cfde0a4b.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="a051ed25-21a3-4e59-a2e5-27c5b590ef94",t._sentryDebugIdIdentifier="sentry-dbid-a051ed25-21a3-4e59-a2e5-27c5b590ef94")}catch{}})();class w{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await y();const t=l(),e=i({render:()=>f(b)});n.init(),r(e,a),w.init(),e.use(a),e.use(t),e.use(o),e.mount("#app"),e.component("VSelect",d),e.component("Markdown",p),e.component("Message",c),s(e,m),s(e,u),s(e,g)})();
//# sourceMappingURL=player.f005b789.js.map
