import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.61fdc5f7.js";import{d as i,ea as s,o as m,c as a,u as f}from"./index.0396e68e.js";import"./gateway.157f1e61.js";import"./popupNotifcation.17433f53.js";import"./fetch.8db10b99.js";import"./record.0e62b813.js";import"./SaveButton.56eabbc2.js";import"./UnsavedChangesHandler.c9eb6f61.js";import"./ExclamationCircleOutlined.9f5a0e68.js";import"./CrudView.80ac9789.js";import"./router.f9d61a0b.js";import"./Badge.1e7f212f.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.0ad17905.js";import"./BookOutlined.9a743874.js";import"./url.892c62bd.js";import"./PhDotsThreeVertical.vue.edbaaf52.js";import"./index.e1b1a35a.js";import"./index.ece7867e.js";import"./asyncComputed.fdf54570.js";import"./polling.14117eb9.js";import"./PhPencil.vue.be504ce9.js";import"./index.445b73ea.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="4294ee8e-fc80-4483-bef1-fa754860e527",e._sentryDebugIdIdentifier="sentry-dbid-4294ee8e-fc80-4483-bef1-fa754860e527")}catch{}})();const A=i({__name:"EnvVars",setup(e){const r=s().params.projectId,t=new p(r);return(c,d)=>(m(),a(n,{"env-var-repository":f(t),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars.8f74c07c.js.map
