import{_ as m}from"./TasksView.vue_vue_type_script_setup_true_lang.6fd739b2.js";import{R as f}from"./tasksController.9fed01d7.js";import{d as b,ea as _,f as y,o as n,Y as g,b as w,w as k,u as l,c as I,S as T,aS as v,aG as B,dd as S}from"./index.0396e68e.js";import"./gateway.157f1e61.js";import{a as j,B as x}from"./build.69ddf786.js";import{a as C}from"./project.f92dad7c.js";import"./tables.c0487350.js";import{a as D}from"./asyncComputed.fdf54570.js";import"./metadata.edcbc4f9.js";import"./PhWebhooksLogo.vue.834c9249.js";import"./ant-design.8b815b73.js";import"./string.dc823a05.js";import"./dayjs.82e48647.js";import"./index.e1b1a35a.js";import"./scripts.79d2de54.js";import"./record.0e62b813.js";import"./linters.13eb7d79.js";import"./polling.14117eb9.js";import"./popupNotifcation.17433f53.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="918e99f8-30b4-4c52-a838-f4ac129b4916",e._sentryDebugIdIdentifier="sentry-dbid-918e99f8-30b4-4c52-a838-f4ac129b4916")}catch{}})();const Q=b({__name:"Tasks",setup(e){const a=_().params.projectId,p=new f(a),{result:o}=D(async()=>{const r=(await j.list(a)).find(d=>d.latest);if(!r)return null;const[u,c]=await Promise.all([x.get(r.id),C.get(a)]);return{buildSpec:u,project:c}}),i=y(()=>!o.value||!o.value.buildSpec?null:o.value.buildSpec.runtimes.map(t=>({id:t.id,stageTitle:t.title,stageType:t.type})));return(t,r)=>(n(),g(v,null,[w(l(S),null,{default:k(()=>[B("Tasks")]),_:1}),i.value?(n(),I(m,{key:0,class:"tasks",api:l(p),stages:i.value},null,8,["api","stages"])):T("",!0)],64))}});export{Q as default};
//# sourceMappingURL=Tasks.d57be4c3.js.map
