import{C as d}from"./gateway.157f1e61.js";import"./index.0396e68e.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="68a897f2-0461-4fad-be8e-912fcdd05ee7",r._sentryDebugIdIdentifier="sentry-dbid-68a897f2-0461-4fad-be8e-912fcdd05ee7")}catch{}})();class s{async list(e){return d.get(`organizations/${e}/folders`)}async create(e){return d.post(`organizations/${e.organizationId}/folders`,{name:e.name,memberIds:e.memberIds})}async delete(e,n){return d.delete(`organizations/${e}/folders/${n}`)}async update(e,n){return d.patch(`organizations/${e}/folders/${n.id}/`,{name:n.name,memberIds:n.memberIds})}}export{s as F};
//# sourceMappingURL=folder.c3887ad2.js.map
