import{L as t}from"./Logo.008d40fa.js";import{d as n,o as r,c as a,u as d}from"./index.0396e68e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="52b1c0db-e6f0-4f4f-b049-57110487e554",e._sentryDebugIdIdentifier="sentry-dbid-52b1c0db-e6f0-4f4f-b049-57110487e554")}catch{}})();const f="/assets/logo.0faadfa2.svg",u=n({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(o,s)=>(r(),a(t,{"image-url":d(f),"brand-name":"Abstra","hide-text":o.hideText,size:o.size},null,8,["image-url","hide-text","size"]))}});export{u as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang.224ac585.js.map
