import{d as i,o as p,c as n,w as m,b as s,u as t}from"./index.0396e68e.js";import"./linters.13eb7d79.js";import{W as d}from"./workspaces.c2ddaf04.js";import{C as a}from"./ContentLayout.da1c7798.js";import{_ as f,E as c}from"./View.vue_vue_type_script_setup_true_lang.61fdc5f7.js";import"./asyncComputed.fdf54570.js";import"./workspaceStore.63e90c7b.js";import"./url.892c62bd.js";import"./colorHelpers.1afbbca5.js";import"./record.0e62b813.js";import"./gateway.157f1e61.js";import"./popupNotifcation.17433f53.js";import"./fetch.8db10b99.js";import"./SaveButton.56eabbc2.js";import"./UnsavedChangesHandler.c9eb6f61.js";import"./ExclamationCircleOutlined.9f5a0e68.js";import"./CrudView.80ac9789.js";import"./router.f9d61a0b.js";import"./Badge.1e7f212f.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.0ad17905.js";import"./BookOutlined.9a743874.js";import"./PhDotsThreeVertical.vue.edbaaf52.js";import"./index.e1b1a35a.js";import"./index.ece7867e.js";import"./polling.14117eb9.js";import"./PhPencil.vue.be504ce9.js";import"./index.445b73ea.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="56735132-32b4-4cef-9857-b786d3cd495d",o._sentryDebugIdIdentifier="sentry-dbid-56735132-32b4-4cef-9857-b786d3cd495d")}catch{}})();const G=i({__name:"EnvVarsEditor",setup(o){const r=new c;return(e,u)=>(p(),n(a,null,{default:m(()=>[s(f,{"env-var-repository":t(r),mode:"editor","file-opener":t(d)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{G as default};
//# sourceMappingURL=EnvVarsEditor.f6b46cb6.js.map
