import{O as r}from"./workspaceStore.63e90c7b.js";import{d as i,X as l,o as c,Y as u,b as a,w as n,u as d,aG as o,dd as f,dc as b}from"./index.0396e68e.js";import"./url.892c62bd.js";import"./colorHelpers.1afbbca5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="01db346b-cd7a-4737-991a-4b57bdc4aefc",e._sentryDebugIdIdentifier="sentry-dbid-01db346b-cd7a-4737-991a-4b57bdc4aefc")}catch{}})();const w=i({__name:"OidcLoginCallback",setup(e){return l(async()=>{await new r().loginCallback()}),(t,s)=>(c(),u("div",null,[a(d(f),null,{default:n(()=>[o("You're authenticated")]),_:1}),a(d(b),null,{default:n(()=>[o(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLoginCallback.97bbb9a8.js.map
